/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * applet1.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */



import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

import java.io.*;


import gov.aps.epics.jca.*;
import gov.aps.epics.jca.dbr.*;



public class applet1 extends JApplet {

  JPanel     _contentPane;
  JTextField _pvname;
  JButton    _search;
  JTextArea  _output;


  Context _context;


  public void init() {
    _contentPane= new JPanel(new BorderLayout());

    _pvname= new JTextField("type your pv name here");
    _pvname.addActionListener(new ActionListener() {
                                public void actionPerformed(ActionEvent ev) {
                                  processSearch(_pvname.getText());
                                }
                              });
    _search= new JButton("search");
    _search.addActionListener(new ActionListener() {
                                public void actionPerformed(ActionEvent ev) {
                                  processSearch(_pvname.getText());
                                }
                              });

    JPanel north= new JPanel();
    BoxLayout bl= new BoxLayout(north, BoxLayout.X_AXIS);
    north.setLayout(bl);


    north.add(_pvname);
    north.add(_search);

    _contentPane.add(north, BorderLayout.NORTH);


    _output= new JTextArea();
//    _output.setPreferredSize(new Dimension(500,500));
    _output.setEditable(false);

    JScrollPane center= new JScrollPane(_output, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS,  JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS);

    _contentPane.add(center, BorderLayout.CENTER);


    setContentPane(_contentPane);
  }


  public void stop() {
    try {
     _context.destroy();
    } catch(Throwable th) {
    } finally {
      _context=null;
    }
  }

  class ProcessThread extends Thread {
    protected String _pv;
    public ProcessThread(String pv) {
      _pv=pv;
    }
    public void run() {
      Channel ch=null;

      try {
        appendText("Connecting channel: "+_pv+"\n");
        ch= _context.createChannel(_pv);
        _context.pendIO(5.0);

        appendText("reading info...\n");
        DBR dbr= ch.get(Ca.DBR_CTRL_DOUBLE, 1);
        _context.pendIO(5.0);

        ByteArrayOutputStream baos= new ByteArrayOutputStream(500);
        PrintStream out= new PrintStream( baos );
        dbr.printInfo(out);
        appendText(baos.toString()+"\n\n");

      } catch (Exception ex) {
        appendText(ex.toString()+"\n\n");
      } finally {
        try {
          ch.destroy();
        } catch (Throwable th) {
        }

        _search.setEnabled(true);
//        _pvname.setText("");
        _pvname.setEnabled(true);
        _pvname.requestFocus();
      }
    }
  }

  protected void appendText(String str) {
    _output.append(str);
    _output.setCaretPosition(_output.getText().length());
  }

  protected void processSearch(String pv) {
    if (pv==null || pv.trim().equals("")) return;

    _pvname.setEnabled(false);
    _search.setEnabled(false);

    try {
      if (_context==null) _context= Ca.createContext("APPLET1", Ca.ENABLE_PREEMPTIVE_CALLBACK, Ca.THREAD_CTRL_INTERNAL);

      new ProcessThread(pv.trim()).start();

    } catch (Exception ex) {
      appendText(ex.toString()+"\n\n");
//      _pvname.setText("");
      _search.setEnabled(true);
      _pvname.setEnabled(true);
      _pvname.requestFocus();
    }
  }



}




