/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * applet2.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */



import java.awt.*;
import javax.swing.*;

import gov.aps.epics.jca.*;
import gov.aps.epics.jca.dbr.*;



public class applet2 extends JApplet implements ConnectionListener {
  Context ctxt;
  Channel channel;
  JPanel contentPane;
  ChannelMeter channelMeter;


  public void init() {
    contentPane= new JPanel(new BorderLayout());

    channelMeter= new ChannelMeter();

    contentPane.add(channelMeter, BorderLayout.CENTER);


    setContentPane(contentPane);

  }

  public void start() {
    try {

      ctxt= Ca.createContext("MyContext", Ca.ENABLE_PREEMPTIVE_CALLBACK, Ca.THREAD_CTRL_INTERNAL);

      String pvname= getParameter("pv");

      channel= ctxt.createChannel(pvname, this);
      ctxt.flushIO();
      showStatus("Connecting to channel: "+pvname);
    } catch (Throwable th) {
      showStatus(th.toString());
    }
  }



  public void connectionChanged(ConnectionEvent ev) {
    showStatus("Connected:"+ev.isConnected());


    if (ev.isConnected()) {
      channelMeter.setChannel((Channel)ev.getSource());
    } else {
      channelMeter.setChannel(null);
    }
  }
}



class ChannelMeter extends JPanel implements MonitorListener {
  Channel channel=null;
  DBR_CTRL_Double dbr=null;

  public void setChannel(Channel ch) {
    channel=ch;
    dbr=null;
    if (ch!=null) {
      try {
        channel.addMonitorListener(Ca.DBR_CTRL_DOUBLE, 1, this, Ca.DBE_VALUE);
        channel.getContext().flushIO();
      } catch (Exception ex) {
        channel=null;
      }
    }
    repaint();
  }


  public void paintComponent(Graphics gr) {
    super.paintComponent(gr);

    Dimension d= getSize();
    int w= d.width;
    int h= d.height;

    if (channel==null) {
      gr.drawString("No channel specified", 50, h/2);
      return;
    }

    if (dbr==null) {
      gr.drawString("Connecting to channel: "+channel.getName(), 50, h/2);
      return;
    }

    double val= dbr.getDoubleValue()[0];

    double udl= dbr.getUpperDispLimit().doubleValue();
    double ldl= dbr.getLowerDispLimit().doubleValue();

    double ual= dbr.getUpperAlarmLimit().doubleValue();
    double uwl= dbr.getUpperWarningLimit().doubleValue();
    double lwl= dbr.getLowerWarningLimit().doubleValue();
    double lal= dbr.getLowerAlarmLimit().doubleValue();



    double max= udl-ldl;


    double inc= d.width/max;

    int law= (int)((lal-ldl)*inc);
    int lww= (int)((lwl-lal)*inc);
    int valw= (int)((uwl-lwl)*inc);
    int uww= (int)((ual-uwl)*inc);
    int uaw= (int)((udl-ual)*inc);

    int pos= (int) ((val-ldl)*inc);



    gr.setColor(Color.red);
    gr.fillRect(0,0, law, h);

    gr.setColor(Color.orange);
    gr.fillRect(0+law, 0, lww, h);

    gr.setColor(Color.green);
    gr.fillRect(0+law+lww, 0, valw, h);

    gr.setColor(Color.orange);
    gr.fillRect(0+law+lww+valw, 0, uww, h);

    gr.setColor(Color.red);
    gr.fillRect(0+law+lww+valw+uww,0, uaw, h);


    gr.setColor(Color.black);
    gr.fillRect(pos-1, 0, 3, h);

  }

  public void monitorChanged(MonitorEvent ev) {
    dbr= (DBR_CTRL_Double) ev.getDBR();
    dbr.printInfo();
    repaint();
  }
}




