/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * example1.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */





import gov.aps.epics.jca.*;
import gov.aps.epics.jca.dbr.*;



public class example1 {
  public static void main(String[] args) {

    if(args.length!=1) {
      System.out.println("usage: javaCA example1 'pvname'");
      System.exit(-1);
    }

    System.out.println("java.library.path= "+System.getProperty("java.library.path",""));

    try {
      System.out.println( "Creating context" );
      Context ctxt= Ca.createContext("MyContext", Ca.ENABLE_PREEMPTIVE_CALLBACK, Ca.THREAD_CTRL_EXTERNAL);


      System.out.println( "\nCreating channel: "+args[0] );
      Channel ch= ctxt.createChannel(args[0]);
      ctxt.pendIO(1.0);

      ch.printInfo();

      System.out.println( "\nWriting string value to channel" );
      ch.put("5.7");
      ctxt.pendIO(1.0);


      System.out.println( "\nReading native type and length value from channel	" );
      DBR val= ch.get();
      ctxt.pendIO(1.0);
      val.printInfo();

      System.out.println( "\nWriting double value to channel" );
      ch.put(15.3);
      ctxt.pendIO(1.0);

      System.out.println( "\nReading a DBR_CTRL_DOUBLE type value from channel" );
      val= ch.get(Ca.DBR_CTRL_DOUBLE, 1);
      ctxt.pendIO(1.0);
      val.printInfo();



      System.out.println( "\nDestroying channel" );
      ch.destroy();

      System.out.println( "\nDestroying context\n" );
      ctxt.destroy();
    }catch(Exception ex) {
      ex.printStackTrace();
      System.exit(-1);
    }

  }
}
