/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * example3.java,v 1.2 2003/10/03 09:36:29 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */





import gov.aps.epics.jca.*;
import gov.aps.epics.jca.dbr.*;



public class example3 {


  static class MonitorCallback implements MonitorListener {
    public void monitorChanged(MonitorEvent ev) {
      System.out.println("MonitorChanged:");
      System.out.println("STATUS= "+ev.getStatus());
      ev.getDBR().printInfo();
      decreaseCount();
    }

    int _count=0;
    public synchronized void increaseCount() { ++_count; }
    public synchronized void decreaseCount() { --_count; }
    public int count() { return _count; }
  }


  public static void main(String[] args) {

    if(args.length!=1) {
      System.out.println("usage: javaCA example2 'pvname'");
      System.exit(-1);
    }

    try {

      Context ctxt;
      Channel ch;
      DBR val;
      MonitorCallback monitorCallback;

      
      //-------------------------------------------------------------

      System.out.println( "Creating context" );
      ctxt= Ca.createContext("MyContext", Ca.ENABLE_PREEMPTIVE_CALLBACK, Ca.THREAD_CTRL_EXTERNAL);


      //-------------------------------------------------------------


      System.out.println( "\nConnecting channel: "+args[0] );
      ch= ctxt.createChannel(args[0]);
      ctxt.pendIO(1.0);

      ch.printInfo();

      // ------------------------------------------------------------

      monitorCallback= new MonitorCallback();
      ch.addMonitorListener(Ca.DBR_TIME_DOUBLE, 1, monitorCallback, Ca.DBE_VALUE);
      ctxt.flushIO();


      //-------------------------------------------------------------

      System.out.println( "\nWriting string value to channel" );
      ch.put("5.7");
      monitorCallback.increaseCount();
      ctxt.pendIO(1.0);


      //-------------------------------------------------------------

      System.out.println( "\nWriting double value to channel" );
      ch.put(15.3);
      monitorCallback.increaseCount();
      ctxt.pendIO(1.0);


      //-------------------------------------------------------------

      int retry=0;
      while(monitorCallback.count()>0 && retry++<10) {
        try {
          Thread.sleep(1000);
        } catch(InterruptedException ie) {}
      }



      System.out.println( "\nDestroying channel" );
      ch.destroy();

      System.out.println( "\nDestroying context\n" );
      ctxt.destroy();


    }catch(Exception ex) {
      ex.printStackTrace();
      System.exit(-1);
    }

  }
}
