/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * example4.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */



import java.io.*;


import gov.aps.epics.jca.*;
import gov.aps.epics.jca.dbr.*;



public class example4 {


  static class MonitorCallback implements MonitorListener {
    public void monitorChanged(MonitorEvent ev) {
      ev.getDBR().printInfo();
      System.out.println();
    }
  }

  static class UpdateThread extends Thread {
    Channel _ch;
    public UpdateThread(Channel ch) {
      _ch=ch;
      setDaemon(true);
    }

    public void run() {
      try {
      Context ctxt= _ch.getContext();

      ctxt.attachCurrentThread();

      double val=0;
      while(true) {
        _ch.put(val++);
        ctxt.flushIO();

        try {
          sleep(1000);
        } catch(InterruptedException ie) {
        }
      }
      } catch(CaException cae) {
        cae.printStackTrace();
        System.out.println("Aborting updateThread");
      } catch(IllegalStateException ise) {
      }
    }

  }


  public static void main(String[] args) {

    if(args.length!=1) {
      System.out.println("usage: javaCA example4 'pvname'");
      System.exit(-1);
    }

    try {

      Context ctxt;
      Channel ch;
      DBR val;
      MonitorCallback monitorCallback;
      UpdateThread    updateThread;

      
      //-------------------------------------------------------------

      System.out.println( "Creating context" );
      ctxt= Ca.createContext("MyContext", Ca.ENABLE_PREEMPTIVE_CALLBACK, Ca.THREAD_CTRL_EXTERNAL);


      //-------------------------------------------------------------


      System.out.println( "\nConnecting channel: "+args[0] );
      ch= ctxt.createChannel(args[0]);
      ctxt.pendIO(1.0);

      ch.printInfo();

      // ------------------------------------------------------------

      System.out.println("hit return to quit");

      try {
        Thread.sleep(1000);
      } catch(InterruptedException ie) {}


      monitorCallback= new MonitorCallback();
      ch.addMonitorListener(monitorCallback, Ca.DBE_VALUE);
      ctxt.flushIO();


      updateThread= new UpdateThread(ch);
      updateThread.start();




      BufferedReader reader= new BufferedReader(new InputStreamReader(System.in));
      try {
        reader.readLine();
      } catch(IOException ioe) {
      }


      System.out.println( "\nDestroying channel" );
      ch.destroy();

      System.out.println( "\nDestroying context\n" );
      ctxt.destroy();


    }catch(Exception ex) {
      ex.printStackTrace();
      System.exit(-1);
    }

  }
}
