/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * DBR.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */



package gov.aps.epics.jca.dbr;

import java.io.PrintStream;

import gov.aps.epics.jca.Ca;


public class DBR implements gov.aps.epics.jca.CaConstants {
  protected int    _type;
  protected int    _count;
  protected Object _value;


  protected DBR(Object value) {
    _value=value;
    _count= java.lang.reflect.Array.getLength(_value);
  }

  public String getTypeString() {
    return Ca.getDBRTypeString(getType());
  }



  public    int  getType()         { return _type; }
  protected void setType(int type) { _type= type;  }

  public int    getCount() { return _count; }
  public Object getValue()  { return _value;  }


  public boolean isBYTE()     { return isBYTE(this);   }
  public boolean isSHORT()    { return isSHORT(this);  }
  public boolean isINT()      { return isINT(this);    }
  public boolean isFLOAT()    { return isFLOAT(this);  }
  public boolean isDOUBLE()   { return isDOUBLE(this); }
  public boolean isSTRING()   { return isSTRING(this); }
  public boolean isENUM()     { return isENUM(this);   }
  public boolean isSTS()      { return isSTS(this);    }
  public boolean isGR()       { return isGR(this);     }
  public boolean isCTRL()     { return isCTRL(this);   }
  public boolean isLABELS()   { return isLABELS(this); }
  public boolean isTIME()     { return isTIME(this);   }
  public boolean isPRECSION() { return isPRECISION(this);   }



  static public boolean isBYTE(DBR dbr) {
    return dbr instanceof BYTE;
  }
  static public boolean isSHORT(DBR dbr) {
    return dbr instanceof SHORT;
  }
  static public boolean isINT(DBR dbr) {
    return dbr instanceof INT;
  }
  static public boolean isFLOAT(DBR dbr) {
    return dbr instanceof FLOAT;
  }
  static public boolean isDOUBLE(DBR dbr) {
    return dbr instanceof DOUBLE;
  }
  static public boolean isSTRING(DBR dbr) {
    return dbr instanceof STRING;
  }
  static public boolean isENUM(DBR dbr) {
    return dbr instanceof ENUM;
  }
  
  static public boolean isSTS(DBR dbr) {
    return dbr instanceof STS;
  }
  static public boolean isGR(DBR dbr) {
    return dbr instanceof GR;
  }
  static public boolean isCTRL(DBR dbr) {
    return dbr instanceof CTRL;
  }
  static public boolean isLABELS(DBR dbr) {
    return dbr instanceof LABELS;
  }
  static public boolean isTIME(DBR dbr) {
    return dbr instanceof TIME;
  }
  static public boolean isPRECISION(DBR dbr) {
    return dbr instanceof PRECISION;
  }

  static public int getDBRType(String dbrname) {
    for(int t=DBR_FIRST; t<=DBR_LAST; ++t) {
      if(dbrname.equals(DBR_TYPE_STRING[t])) return t;
    }
    return -1;
  }


  public void printInfo() {
    printInfo(System.out);
  }

  public void printInfo(PrintStream out) {
    out.println("TYPE     : "+getTypeString());
    out.println("COUNT    : "+getCount());
    out.print  ("VALUE    : ");
    Object value= getValue();
    if     (value instanceof byte[])   Ca.printValue((byte[])value, out);
    else if(value instanceof short[])  Ca.printValue((short[])value, out);
    else if(value instanceof int[])    Ca.printValue((int[])value, out);
    else if(value instanceof float[])  Ca.printValue((float[])value, out);
    else if(value instanceof double[]) Ca.printValue((double[])value, out);
    else if(value instanceof String[]) Ca.printValue((String[])value, out);
    out.println();
  }



}


