/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * DBRFactory.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */





package gov.aps.epics.jca.dbr;


public class DBRFactory implements gov.aps.epics.jca.CaConstants {


  static public DBR create(int type, int count) {
    switch(type) {

      case DBR_STRING:      return new DBR_String(count);
      case DBR_STS_STRING:  return new DBR_STS_String(count);
      case DBR_TIME_STRING: return new DBR_TIME_String(count);

      case DBR_ENUM:        return new DBR_Enum(count);
      case DBR_STS_ENUM:    return new DBR_STS_Enum(count);
      case DBR_TIME_ENUM:   return new DBR_TIME_Enum(count);
      case DBR_LABELS_ENUM: return new DBR_LABELS_Enum(count);
      case DBR_CTRL_ENUM:   return new DBR_LABELS_Enum(count);

      case DBR_BYTE:        return new DBR_Byte(count);
      case DBR_STS_BYTE:    return new DBR_STS_Byte(count);
      case DBR_TIME_BYTE:   return new DBR_TIME_Byte(count);
      case DBR_GR_BYTE:     return new DBR_GR_Byte(count);
      case DBR_CTRL_BYTE:   return new DBR_CTRL_Byte(count);

      case DBR_SHORT:       return new DBR_Short(count);
      case DBR_STS_SHORT:   return new DBR_STS_Short(count);
      case DBR_TIME_SHORT:  return new DBR_TIME_Short(count);
      case DBR_GR_SHORT:    return new DBR_GR_Short(count);
      case DBR_CTRL_SHORT:  return new DBR_CTRL_Short(count);

      case DBR_INT:         return new DBR_Int(count);
      case DBR_STS_INT:     return new DBR_STS_Int(count);
      case DBR_TIME_INT:    return new DBR_TIME_Int(count);
      case DBR_GR_INT:      return new DBR_GR_Int(count);
      case DBR_CTRL_INT:    return new DBR_CTRL_Int(count);

      case DBR_FLOAT:       return new DBR_Float(count);
      case DBR_STS_FLOAT:   return new DBR_STS_Float(count);
      case DBR_TIME_FLOAT:  return new DBR_TIME_Float(count);
      case DBR_GR_FLOAT:    return new DBR_GR_Float(count);
      case DBR_CTRL_FLOAT:  return new DBR_CTRL_Float(count);

      case DBR_DOUBLE:      return new DBR_Double(count);
      case DBR_STS_DOUBLE:  return new DBR_STS_Double(count);
      case DBR_TIME_DOUBLE: return new DBR_TIME_Double(count);
      case DBR_GR_DOUBLE:   return new DBR_GR_Double(count);
      case DBR_CTRL_DOUBLE: return new DBR_CTRL_Double(count);

      case DBR_STSACK_STRING: return new DBR_STSACK_String(count);
      case DBR_PUT_ACKS     : return new DBR_PutAckS(count);
      case DBR_PUT_ACKT     : return new DBR_PutAckT(count);
    }
    throw new IllegalArgumentException("Unsupported type");
  }

}


