/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * DBR_GR_Short.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */




package gov.aps.epics.jca.dbr;

import java.io.*;

public class DBR_GR_Short extends DBR_STS_Short implements GR {
  protected String _unit=EMPTYUNIT;
  protected Short  _udl=ZEROS;
  protected Short  _ldl=ZEROS;
  protected Short  _ual=ZEROS;
  protected Short  _uwl=ZEROS;
  protected Short  _lwl=ZEROS;
  protected Short  _lal=ZEROS;

  public DBR_GR_Short() {
    this(1);
  }
  public DBR_GR_Short(int count) {
    this(new short[count]);
  }
  public DBR_GR_Short(short[] value) {
    super(value);
    setType(DBR_GR_SHORT);
  }

  public String getUnits()            { return _unit; }
  public void   setUnits(String unit) { _unit= unit;  }

  public Number getUpperDispLimit()                { return _udl; }
  public void   setUpperDispLimit(Number limit)    { _udl= new Short(limit.shortValue()); }
  public Number getLowerDispLimit()                { return _ldl; }
  public void   setLowerDispLimit(Number limit)    { _ldl= new Short(limit.shortValue()); }
  public Number getUpperAlarmLimit()               { return _ual; }
  public void   setUpperAlarmLimit(Number limit)   { _ual= new Short(limit.shortValue()); }
  public Number getUpperWarningLimit()             { return _uwl; }
  public void   setUpperWarningLimit(Number limit) { _uwl= new Short(limit.shortValue()); }
  public Number getLowerWarningLimit()             { return _lwl; }
  public void   setLowerWarningLimit(Number limit) { _lwl= new Short(limit.shortValue()); }
  public Number getLowerAlarmLimit()               { return _lal; }
  public void   setLowerAlarmLimit(Number limit)   { _lal= new Short(limit.shortValue()); }

  public void printInfo(PrintStream out) {
    super.printInfo(out);
    out.println("UNITS    : "+ getUnits());
    out.println("UDL      : "+ getUpperDispLimit());
    out.println("LDL      : "+ getLowerDispLimit());
    out.println("UAL      : "+ getUpperAlarmLimit());
    out.println("UWL      : "+ getUpperWarningLimit());
    out.println("LWL      : "+ getLowerWarningLimit());
    out.println("LAL      : "+ getLowerAlarmLimit());
  }

}

