/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * JNIContext.java,v 1.1.1.1 2003/09/11 14:42:49 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */


package gov.aps.epics.jca.jni;

import gov.aps.epics.jca.*;
import gov.aps.epics.jca.dbr.*;

import java.util.LinkedList;
import java.util.HashMap;
import java.lang.ref.WeakReference;


abstract public class JNIContext extends Context {

  protected int _ctxtID;
  protected void setCtxtID(int ctxtID) { _ctxtID= ctxtID; }
  protected int  getCtxtID() { return _ctxtID; }

  public String getName() {
    return ctxt_getName();
  }

  public int getThreadCtrlMode() {
    return ctxt_getThreadCtrlMode();
  }

  public int getCallbackMode() {
    return ctxt_getCallbackMode();
  }

  protected ContextMessageListener _messageListener;

  public ContextMessageListener getContextMessageListener() {
    return _messageListener;
  }

  public void setContextMessageListener(ContextMessageListener l) throws CaException {
    ctxt_setMessageListener(l);
    _messageListener=l;
  }


  protected ContextExceptionListener _exceptionListener;

  public ContextExceptionListener getContextExceptionListener() {
    return _exceptionListener;
  }
  
  public void setContextExceptionListener(ContextExceptionListener l) throws CaException {
    ctxt_setExceptionListener(l);
    _exceptionListener=l;
  }

  public void destroy() throws CaException {
    ctxt_contextDestroy();
  }

  public Channel createChannel(String name, ConnectionListener l) throws CaException {
    JNIChannel ch= ch_channelCreate(name, l);
    registerChannel(ch);
    return ch;
  }

  public void pendIO(double timeout) throws CaException {
    ctxt_pendIO(timeout);
  }

  public boolean testIO() throws CaException {
    return ctxt_testIO();
  }

  public void pendEvent(double time) throws CaException {
    ctxt_pendEvent(time);
  }

  public void poll() throws CaException {
    ctxt_poll();
  }

  public void flushIO() throws CaException {
    ctxt_flushIO();
  }

  public void attachCurrentThread() throws CaException {
    ctxt_attachThread();
  }



  HashMap _channelMap= new HashMap();

  public void registerChannel(JNIChannel ch) {
    if(ch==null) return;
    _channelMap.put(new Integer(ch.getChannelID()), new WeakReference(ch));
  }

  public JNIChannel lookupChannel(int channelID) {
    WeakReference ref= (WeakReference) _channelMap.get(new Integer(channelID));
    if(ref==null) return null;
    return (JNIChannel) ref.get();
  }

  public void unregisterChannel(JNIChannel ch) {
    if(ch==null) return;
    _channelMap.remove(new Integer(ch.getChannelID()));
  }


  abstract public int ctxt_getThreadCtrlMode();

  abstract public int ctxt_getCallbackMode();

  abstract public String ctxt_getName();

  abstract public int  ctxt_contextCreate(int mode) throws CaException;

  abstract public void ctxt_setMessageListener(ContextMessageListener l) throws CaException;
  
  abstract public void ctxt_setExceptionListener(ContextExceptionListener l) throws CaException;

  abstract public void ctxt_contextDestroy() throws CaException;


  abstract public void ctxt_pendIO(double timeout) throws CaException;

  abstract public boolean ctxt_testIO() throws CaException;

  abstract public void ctxt_pendEvent(double time) throws CaException;

  abstract public void ctxt_poll() throws CaException;

  abstract public void ctxt_flushIO() throws CaException;

  abstract public void ctxt_attachThread() throws CaException;

  abstract public JNIChannel ch_channelCreate(String name, ConnectionListener l) throws CaException;

  abstract public void ch_channelDestroy(JNIChannel ch) throws CaException;

  abstract public void ch_setConnectionListener(JNIChannel ch, ConnectionListener l) throws CaException;

  abstract public void ch_setAccessRightsListener(JNIChannel ch, AccessRightsListener l) throws CaException;

  abstract public int ch_getFieldType(JNIChannel ch);

  abstract public int ch_getElementCount(JNIChannel ch);

  abstract public int ch_getState(JNIChannel ch);

  abstract public String ch_getHostName(JNIChannel ch);

  abstract public boolean ch_getReadAccess(JNIChannel ch);

  abstract public boolean ch_getWriteAccess(JNIChannel ch);


  abstract public void ch_arrayPut(int type, int count, JNIChannel ch, Object value) throws CaException;

  abstract public void ch_arrayPut(int type, int count, JNIChannel ch, Object value, PutListener l) throws CaException;

  abstract public void ch_arrayGet(DBR dbr, JNIChannel ch) throws CaException;

  abstract public void ch_arrayGet(int type, int count, JNIChannel ch, GetListener l) throws CaException;


  abstract public JNIMonitor ch_addMonitor(int type, int count, JNIChannel ch, MonitorListener l, int mask) throws CaException;

  abstract public void ch_clearMonitor(JNIMonitor monitor) throws CaException;


}



