/**********************************************************************
 * 
 *      Original Author: Eric Boucher
 *      Date:            05/05/2003
 *
 *      Experimental Physics and Industrial Control System (EPICS)
 *
 *      Copyright 1991, the University of Chicago Board of Governors.
 *
 *      This software was produced under  U.S. Government contract
 *      W-31-109-ENG-38 at Argonne National Laboratory.
 *
 *      Beamline Controls & Data Acquisition Group
 *      Experimental Facilities Division
 *      Advanced Photon Source
 *      Argonne National Laboratory
 *
 *
 * DBR_CTRL_DBInt.java,v 1.1.1.1 2003/09/11 14:42:50 boucher Exp
 *
 * Modification Log:
 * 01. 05/07/2003  erb  initial development
 *
 */

package jca.dbr;
import java.lang.*;

/**
 * This class represents the Channel Access DBR_CTRL_LONG type.
 *
 */
public class DBR_CTRL_DBInt extends DBR_GR_DBInt implements DBR_CTRL {
  private int   m_upper_ctrl_limit;
  private int   m_lower_ctrl_limit;

  /**
   * Create a new DBR_CTRL_DBInt object to hold 1 value.
   */
  public DBR_CTRL_DBInt() {
    super(1);
  }
  
  /**
   * Create a new DBR_CTRL_DBInt object to hold count value.
   *
   * @param count the number of values to be held by this object.
   */
  public DBR_CTRL_DBInt(int count) {
    super(count);
  }

  /**
   * Return the Channel Access request type.
   */
  public int type() {
    return DBR.CTRL_INT;
  }

  /**
   * Return the upper control limit.
   */
  public DBData upperCtrlLimit() {
    return new DBInt(m_upper_ctrl_limit);
  }

  /** 
   * Return the lower control limit.
   */
  public DBData lowerCtrlLimit() {
    return new DBInt(m_lower_ctrl_limit);
  }

  public void update(gov.aps.epics.jca.dbr.DBR source) {
    super.update(source);

    gov.aps.epics.jca.dbr.CTRL gr= (gov.aps.epics.jca.dbr.CTRL)source;

    m_upper_ctrl_limit   = gr.getUpperCtrlLimit().intValue();
    m_lower_ctrl_limit   = gr.getLowerCtrlLimit().intValue();

  }
/*
  protected void setInfo(short status, short severity,
                      String units,
                      int upper_disp_limit,
                      int lower_disp_limit,
                      int upper_alarm_limit,
                      int upper_warning_limit,
                      int lower_warning_limit,
                      int lower_alarm_limit,
                      int upper_ctrl_limit,
                      int lower_ctrl_limit) {
    super.setInfo(status,severity,
                  units,
                  upper_disp_limit,
                  lower_disp_limit,
                  upper_alarm_limit,
                  upper_warning_limit,
                  lower_warning_limit,
                  lower_alarm_limit);
    m_upper_ctrl_limit= upper_ctrl_limit;
    m_lower_ctrl_limit= lower_ctrl_limit;
  };                      
*/  
}
